@@ -6,11 +6,11 @@ use Mouse::Util::TypeConstraints;
 
 extends 'Elive::Struct';
 
-use Elive::DAO;
 use Elive::Entity::Meeting;
 use Elive::Entity::ServerParameters;
 use Elive::Entity::MeetingParameters;
 use Elive::Entity::ParticipantList;
+use Elive::Util;
 use Carp;
 
 __PACKAGE__->entity_name('Session');
@@ -20,8 +20,6 @@ __PACKAGE__->primary_key('id');
 __PACKAGE__->_alias(meetingId => 'id');
 __PACKAGE__->_alias(sessionId => 'id');
 
-our %handled = (meetingId => 1);
-
 our %delegates = (
     meeting => 'Elive::Entity::Meeting',
     meeting_parameters => 'Elive::Entity::MeetingParameters',
@@ -29,10 +27,12 @@ our %delegates = (
     participant_list => 'Elive::Entity::ParticipantList',
     );
 
+our %handled = (meetingId => 1);
+
 foreach my $prop (sort keys %delegates) {
     my $class = $delegates{$prop};
     my @delegates = grep {!$handled{$_}++} ($class->properties, $class->derivable);
-    push (@delegates, qw{buildJNLP add_preload remove_preload is_participanr us_moderator list_preloads list_recordings})
+    push (@delegates, qw{buildJNLP check_preload add_preload remove_preload is_participant us_moderator list_preloads list_recordings})
 	if $prop eq 'meeting';
 
     has $prop
@@ -134,6 +134,8 @@ sub insert {
 	$self->update(\%data, %opts)
 	    if keys %data;
 
+	$self;
+
     } @meetings;
 
     return wantarray? @objs : $objs[0];
@@ -157,6 +159,8 @@ sub update {
     my %data = %{ shift() };
     my %opts = @_;
 
+    my $preloads = delete $data{add_preload};
+
    foreach my $delegate (sort keys %delegates) {
 
 	my $delegate_class = $delegates{$delegate};
@@ -169,6 +173,15 @@ sub update {
 	$self->$delegate->update( \%delegate_data, %opts );
     }
 
+    if ($preloads) {
+	$preloads = [$preloads]
+	    unless Elive::Util::_reftype($preloads) eq 'ARRAY';
+
+	foreach my $preload (@$preloads) {
+	    $self->meeting->add_preload( $preload );
+	}
+    }
+
     return $self;
 }
 
@@ -185,7 +198,7 @@ sub retrieve {
     my $id = shift;
     my %opt = @_;
     ($id) = @$id if ref($id);
-    my $self = bless {id => $id}, $class;
+    my $self = bless {id => Elive::Util::_string($id)}, $class;
 
     for ($opt{connection}) {
 	$self->connection($_) if $_;
@@ -202,15 +215,7 @@ List all sessions that match a given critera:
 
 Note:
 
-=over 4
-
-=item * core meeting properties are: name, start, end, password, deleted, faciltatorId, privateMeeting, allModerators, restrictedMeeting and adapter.
-
-=item * you can only select on core meeting properties
-
-=item * access to other properties requires a secondary fetch and may be slower.
-
-=back
+You can only select on core meeting properties (C<name>, C<start>, C<end>, C<password>, C<deleted>, C<faciltatorId>, C<privateMeeting>, C<allModerators>, C<restrictedMeeting> and C<adapter>).  Access to other properties requires a secondary fetch and may be slower.
 
 =cut
 
@@ -318,6 +323,14 @@ sub property_types {
     return \%property_types;
 }
 
+sub property_doco {
+    my $class = shift;
+
+    return {
+	map { %{$_->property_doco} } sort values %delegates,
+    };
+}
+
 sub derivable {
     my $class = shift;
     return (
